pub fn dispatch(cmd: LiveCmd) -> ExitCodeExpand description
Top-level entry point invoked by [crate::main]. Builds a runtime,
drives the async dispatch, and folds the resulting LiveCmdError
to an ExitCode via LiveCmdError::exit_code.
pub fn dispatch(cmd: LiveCmd) -> ExitCodeTop-level entry point invoked by [crate::main]. Builds a runtime,
drives the async dispatch, and folds the resulting LiveCmdError
to an ExitCode via LiveCmdError::exit_code.